==> apeman-commons-logging-2.0.0.tgz: package/lib/apeman_ui_logger.js <==
/**
 * Create a logger for apeman ui package.
 * @memberof module:apeman-commons-logging/lib
 * @function apemanUiLogger
 * @param {object} [options] - Optional settings.
 * @param {string} [options.name] - Name of log.
 * @param {boolean} [options.verbose] - Should emit verbose.
 * @returns {Logger} - A logger instance.
 */

"use strict";

var Logger = require('./logger'),
    MessageFormatter = require('./message_formatter'),
    util = require('util');

/** @lends apemanUiLogger */
function apemanUiLogger(options) {
    options = options || {};
    var name = options.name || 'apeman-ui',
        verbose = !!options.verbose;
    return new Logger({
        verbose: verbose,
        PREFIX: util.format('[%s] ', name),
        /**
         * Print about ui start.
         */
        printUiStart: function () {
            var s = this;
            s.info('Start UI building..');
        },
        /**
         * Print about ui done.
         */
        printUiDone: function () {
            var s = this;
            s.info('..building UI done!');
        },
        /**
         * Print about ui fail.
         * @param {Error} err
         */
        printUiFailed: function (err) {
            var s = this;
            s.error(err.stack || err.msg || err);
        },
        /**
         * Print about config.
         * @param {object} config - Config to log.
         */
        printConfig: function (config) {
            var s = this;
            s.trace("%s", config);
        }
    });
}

module.exports = apemanUiLogger;

==> apeman-commons-logging-2.0.1.tgz: package/lib/apeman_ui_logger.js <==
/**
 * Create a logger for apeman ui package.
 * @memberof module:apeman-commons-logging/lib
 * @function apemanUiLogger
 * @param {object} [options] - Optional settings.
 * @param {string} [options.name] - Name of log.
 * @param {boolean} [options.verbose] - Should emit verbose.
 * @returns {Logger} - A logger instance.
 */

"use strict";

var Logger = require('./console_logger'),
    MessageFormatter = require('./message_formatter'),
    util = require('util');

/** @lends apemanUiLogger */
function apemanUiLogger(options) {
    options = options || {};
    var name = options.name || 'apeman-ui',
        verbose = !!options.verbose;
    return new Logger({
        verbose: verbose,
        PREFIX: util.format('[%s] ', name),
        /**
         * Print about ui start.
         */
        printUiStart: function () {
            var s = this;
            s.info('Start UI building..');
        },
        /**
         * Print about ui done.
         */
        printUiDone: function () {
            var s = this;
            s.info('..building UI done!');
        },
        /**
         * Print about ui fail.
         * @param {Error} err
         */
        printUiFailed: function (err) {
            var s = this;
            s.error(err.stack || err.msg || err);
        },
        /**
         * Print about config.
         * @param {object} config - Config to log.
         */
        printConfig: function (config) {
            var s = this;
            s.trace("%s", config);
        }
    });
}

module.exports = apemanUiLogger;
